@@ -81,9 +81,17 @@ void output_header(Project* project, char* title, char* script_name, NaviType na
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/../index.%s/%s/setting_file/user.css\" />\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url);
     o(      "\t<link rel=\"shortcut icon\" type=\"image/x-ico\" href=\"%s/../favicon.ico\" />\n", cgiScriptName);
     if (script_name) {
+        String* locale_a = string_new();
+        locale_a = db_top_get_locale(locale_a);
+        o(  "\t<link rel=\"gettext\" href=\"%s/../js/lang/%s.json\" />\n", cgiScriptName, string_rawstr(locale_a));
+        string_free(locale_a);
+        o(  "\t<script type=\"text/javascript\" src=\"%s/../js/Gettext.js\"></script>\n", cgiScriptName);
+        o(  "\t<script type=\"text/javascript\">\n"
+            "\t\tvar gt = new Gettext({\"domain\": \"starbug1\"});\n"
+            "\t\tfunction _ (msgid) { return gt.gettext(msgid); }\n"
+            "\t</script>\n");
         o(  "\t<script type=\"text/javascript\" src=\"%s/../js/prototype.js\"></script>\n", cgiScriptName);
         o(  "\t<script type=\"text/javascript\" src=\"%s/../js/tooltip.js\"></script>\n", cgiScriptName);
-        o(  "\t<script type=\"text/javascript\" src=\"%s/../index.%s/top/top_gettext_js\"></script>\n", cgiScriptName, get_ext(cgiScriptName));
         o(  "\t<script type=\"text/javascript\" src=\"%s/../js/%s\"></script>\n", cgiScriptName, script_name);
     }
     o(      "</head>\n"
