@@ -33,8 +33,10 @@ List* db_get_statictics_multi(Database*, List*, const int);
 List* db_get_statictics(Database*, List*, const int);
 ElementFile* db_get_element_file(Database*, int, ElementFile*);
 List* db_get_newest_information(Database*, const int, List*);
+bool db_get_element_file_deleted(Database*, int);
 char* db_get_element_file_mime_type(Database*, const int, const int, char*);
 int db_get_element_file_id(Database*, const int, const int);
+void db_delete_element_file(Database*, const int, const bool);
 void db_register_wiki(Database*, Wiki*);
 Wiki* db_get_newest_wiki(Database*, char*, Wiki*);
 void db_setting_file_save(Database*, SettingFile*);
