@@ -158,8 +158,7 @@ void pipe_to_file(char* command_str, char* db_name, FILE* out)
     while (1) {
         char str[DEFAULT_LENGTH];
         if (fgets(str, DEFAULT_LENGTH, fp) == NULL) {
-            pclose(fp);
-            die("外部プログラムの実行結果取得に失敗しました。");
+            break;
         }
         if(feof(fp)){
             break;
